@@ -7,7 +7,7 @@ use warnings;
 use autodie;
 use namespace::autoclean;
 
-our $VERSION = '0.71';
+our $VERSION = '0.72';
 
 use Dist::Zilla 6.0;
 
@@ -757,7 +757,7 @@ Dist::Zilla::PluginBundle::DROLSKY - DROLSKY's plugin bundle
 
 =head1 VERSION
 
-version 0.71
+version 0.72
 
 =head1 SYNOPSIS
 
@@ -775,7 +775,7 @@ version 0.71
     ; Default is DROLSKY
     authority = DROLSKY
     ; Passed to AutoPrereqs - can be repeated
-    prereqs_skkip = ...
+    prereqs_skip = ...
     ; Passed to Test::Pod::Coverage::Configurable if set
     pod_coverage_class = ...
     ; Oassed to Test::Pod::Coverage::Configurable if set - can be repeated
